importFrom(methods, setMethod, is)		 
importFrom(utils, packageDescription, browseURL, type.convert)		 
importFrom(stats, na.omit, reshape)
importFrom(tools, startDynamicHelp)  	 
importFrom(jsonlite, toJSON)
importFrom(jsonlite, unbox)
# Methods     
S3method(plot, gvis)		 
S3method(print, gvis)

# gvis Charts
export(gvisMotionChart)		 
export(gvisGeoMap)
export(gvisTreeMap)
export(gvisTable)
export(gvisPieChart)
export(gvisGauge)
export(gvisOrgChart)
export(gvisBubbleChart)
export(gvisAnnotatedTimeLine)
export(gvisMap)
export(gvisGeoChart)
export(gvisScatterChart)  	 
export(gvisLineChart)
export(gvisAreaChart)
export(gvisBarChart)
export(gvisColumnChart)		 
export(gvisComboChart)		 
export(gvisCandlestickChart)
export(gvisSteppedAreaChart)		 
export(gvisCalendar)
export(gvisHistogram)     
export(gvisAnnotationChart)
export(gvisTimeline)     
export(gvisSankey)
export(gvisWordTree)
export(gvisGantt)

# Support function
export(renderGvis)
export(createGoogleGadget)
export(gvisMerge)
			 
