# googleVis 
<!-- badges: start -->
[![R-CMD-check](https://github.com/mages/googleVis/workflows/R-CMD-check/badge.svg)](https://github.com/mages/googleVis/actions)
<!-- badges: end -->
[![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/googleVis)](https://cran.r-project.org/package=googleVis) [![downloads](https://cranlogs.r-pkg.org/badges/grand-total/googleVis)](https://cran.r-project.org/package=googleVis)


The googleVis package provides an interface between R and the [Google's charts tools](https://developers.google.com/chart/). 
It allows users to create web pages with interactive charts based on R data frames. Charts are displayed locally via the R HTTP help server. 
A modern browser with Internet connection is required. The data remains local and is not uploaded to 
Google.

Check out the [examples](https://mages.github.io/googleVis/articles/googleVis_examples.html) from the googleVis demo.   

Please read [Google's Terms of Use](https://developers.google.com/terms/) before you start using the package. 

## Installation

You can install the stable version from
[CRAN](https://cran.r-project.org/package=googleVis/):

```s
install.packages('googleVis')
```

## Usage

```s
library(googleVis)
?googleVis
demo(googleVis)
```

See the googleVis package [vignette](https://mages.github.io/googleVis/articles/googleVis_intro.html) for more details. For a brief introduction read the five page [R Journal article](https://journal.r-project.org/archive/2011-2/RJournal_2011-2_Gesmann+de~Castillo.pdf).

## License

This package is free and open source software, licensed under GPL 2 or later.

<a rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/deed.en"><img alt="Creative Commons Licence" class="c1" src="https://i.creativecommons.org/l/by-sa/4.0/80x15.png" /></a><br />
<span>googleVis documentation</span> by <a href="https://github.com/mages/googleVis" rel="cc:attributionURL">Markus Gesmann &amp; Diego de Castillo</a> is licensed under a <a rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/deed.en">Creative Commons Attribution-ShareAlike 4.0 International License</a>