\name{dino}
\alias{dino}
\docType{data}
\title{
Dinosaur data
}
\description{
Lenght of dinosaurs
}
\usage{data(dino)}
\format{
  A data frame with 28 observations on 2 variables, dinosaur and length.
}
%\details{
%%  ~~ If necessary, more details than the __description__ above ~~
%}
\source{
  \url{https://developers.google.com/chart/interactive/docs/gallery/histogram}
}
%\references{
%%  ~~ possibly secondary sources and usages ~~
%}
\examples{
data(dino)
str(dino) 
}
\keyword{datasets}
